@@ -215,6 +215,10 @@ class BottleClient:
             nodes = self.query_nodes
         return self._query(requests.post, 'predictions', nodes=nodes, unique_id=unique_id)
 
+    def get_hive_prediction_utility(self) -> dict:
+        """Return prediction result data."""
+        return requests.get(f'{self.url}predictions/utility', headers=self.headers).json()
+
     def clear_wm(self, nodes: List = None) -> List:
         """Clear the Working Memory of the Genie."""
         if nodes is None:
